@@ -24,4 +24,4 @@
 # *
 # **************************************************************************
 
-from protocol_empiar_submission import EmpiarDepositor
\ No newline at end of file
+from .protocol_empiar_submission import EmpiarDepositor
